@@ -5,9 +5,10 @@ from .model import Model
 
 
 def Column(
-    sqltype: TypeEngine,
+    *args,
     primary_key: bool = None,
     nullable: bool = None,
+    unique: bool = None,
 ): pass
 
 
